@@ -14,20 +14,12 @@ package_name = package['name'].replace(' ', '_').replace('-', '_')
 __version__ = package['version']
 
 # Module imports trigger a dash.development import, need to check this first
-if not hasattr(_dash, 'development'):
+if not hasattr(_dash, '__plotly_dash') and not hasattr(_dash, 'development'):
     print("Dash was not successfully imported. Make sure you don't have a file "
           "named \n'dash.py' in your current directory.", file=_sys.stderr)
     _sys.exit(1)
 
-# Must update to dash>=0.23.1 to use this version of dash-core-components
-if not hasattr(_dash.development.base_component, '_explicitize_args'):
-    print("Please update the `dash` module to >= 0.23.1 to use this "
-          "version of dash_core_components.\n"
-          "You are using version {:s}".format(_dash.version.__version__),
-          file=_sys.stderr)
-    _sys.exit(1)
-
-from ._imports_ import *  # noqa: F401, F403
+from ._imports_ import *  # noqa: F401, F403, E402
 from ._imports_ import __all__  # noqa: E402
 
 _current_path = _os.path.dirname(_os.path.abspath(__file__))
